var indexSectionsWithContent =
{
  0: "<_abcdefghiklmnopqrstuvwy",
  1: "dltw",
  2: "abcdefilmprstuw",
  3: "_abcdefghiklmpqrstuvw",
  4: "_deqrtwy",
  5: "_fitu",
  6: "_",
  7: "<acdeu",
  8: "abdfghimptu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "groups",
  8: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Modules",
  8: "Pages"
};

